pitchtools.HarmonicObject
=========================

.. abjad-lineage:: abjad.tools.pitchtools.HarmonicObject.HarmonicObject.HarmonicObject

.. autoclass:: abjad.tools.pitchtools.HarmonicObject.HarmonicObject.HarmonicObject
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.HarmonicObject.HarmonicObject.HarmonicObject.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.HarmonicObject.HarmonicObject.HarmonicObject.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.HarmonicObject.HarmonicObject.HarmonicObject.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.HarmonicObject.HarmonicObject.HarmonicObject.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.HarmonicObject.HarmonicObject.HarmonicObject.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.HarmonicObject.HarmonicObject.HarmonicObject.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.HarmonicObject.HarmonicObject.HarmonicObject.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.HarmonicObject.HarmonicObject.HarmonicObject.__repr__
   :noindex:
